- don't say it **leon** [Done, not tested]
- negotiation **leon** [Done, not tested]
- chess **leon** [Done, not tested]
- truth or deception **leon** [Done, not tested / Also, fact-check the actual facts]
- word chains **leon** [Done, not tested]

- spelling bee **leon** [Done, not tested]
- connect four **leon** [Done, not tested]
- Liar's dice **leon** [Done, not tested]
- taboo **leon** [Done, not tested]
- debate **leon** [Done, not tested]
- scenario planning **leon** [Done, not tested]


- poker **leon** [Buggy, not done]
- car puzzle **leon** [Buggy, not done]


- car puzzle **leon**
- math proof **leon**
- code creation **leon**


- iterated prisoners dilemma with chat **Dylan** [Done]
<<<<<<< HEAD





- memory game **Bobby**
- Letter Auction: Players "bid" on letters to form the highest-scoring word. Each player has a limited number of points to bid with, and the goal is to assemble the highest-value word from the letters won. **Anybody**

# Maybe
- battleship **Bobby**
- Mastermind **Bobby**

- 3 economics games from the leshem paper
- Brass (works with poker chips)
- Le Havre
-  haven’t played it other than a learning game, but perhaps Arkwright is good at 2
- 1862
- Curious Cargo
- Nippon
- Clans of Caledonia
- Pipeline
- Gallerist
- 1860
- Age of Steam
- Ground Floor
- Clinic
- Tramways
- Yokohama

https://playingcarddecks.com/blogs/all-in/the-very-best-two-player-card-games?srsltid=AfmBOop3Moti_sRBP4KIJLAKSl7OFNpnqLDHj_ZpQJMn7QutktbhoO7a
=======
- memory game **Bobby** [Done]

- Letter Auction: Players "bid" on letters to form the highest-scoring word. Each player has a limited number of points to bid with, and the goal is to assemble the highest-value word from the letters won. **Bobby** [done]

- Spite and Malice **Bobby** [done]

# Maybe
- battleship **Bobby** [done]
- Mastermind **Bobby** [done]
>>>>>>> b043a45e9c22a5b92e479d13c476b9e90d44ff27
